 include/vlc_codec.h                      |    3 +++
 modules/stream_out/transcode/transcode.c |   17 +++++++++++++++--
 2 files changed, 18 insertions(+), 2 deletions(-)

diff --git a/include/vlc_codec.h b/include/vlc_codec.h
index beac8fd..0750292 100644
--- a/include/vlc_codec.h
+++ b/include/vlc_codec.h
@@ -173,6 +173,9 @@ struct encoder_t
 
     /* Encoder config */
     config_chain_t *p_cfg;
+    
+    /* Does the encoder need purging at EOF? */
+    bool b_purge_required;
 };
 
 /**
diff --git a/modules/stream_out/transcode/transcode.c b/modules/stream_out/transcode/transcode.c
index f9f5e64..27a9e70 100644
--- a/modules/stream_out/transcode/transcode.c
+++ b/modules/stream_out/transcode/transcode.c
@@ -155,6 +155,7 @@ static const char *const ppsz_deinterlace_type[] =
 
 static int  Open ( vlc_object_t * );
 static void Close( vlc_object_t * );
+static void PurgeAudioEncoder(sout_stream_t *p_stream, sout_stream_id_t *id);
 
 #define SOUT_CFG_PREFIX "sout-transcode-"
 
@@ -625,8 +626,9 @@ static int Del( sout_stream_t *p_stream, sout_stream_id_t *id )
     {
         switch( id->p_decoder->fmt_in.i_cat )
         {
-        case AUDIO_ES:
-            transcode_audio_close( id );
+        case AUDIO_ES: 
+            PurgeAudioEncoder(p_stream, id);
+            transcode_audio_close( id, false );
             break;
         case VIDEO_ES:
             Send( p_stream, id, NULL );
@@ -669,6 +671,17 @@ static int Del( sout_stream_t *p_stream, sout_stream_id_t *id )
     return VLC_SUCCESS;
 }
 
+static void PurgeAudioEncoder(sout_stream_t *p_stream, sout_stream_id_t *id)
+{
+    block_t *p_block = NULL;
+    
+    if ( id->p_encoder->b_purge_required == false )
+        return;
+    p_block = id->p_encoder->pf_encode_audio( id->p_encoder, NULL );
+    if( p_block  )
+        sout_StreamIdSend( p_stream->p_next, id->id, p_block );
+}
+
 static int Send( sout_stream_t *p_stream, sout_stream_id_t *id,
                  block_t *p_buffer )
 {
